---
name: Feature request
about: Suggest an idea for this project
title: "[REQUEST]"
labels: enhancement

---

**Type of Request**
  - [ ] Functionality
  - [ ] Documentation
  - [ ] Quality of Life
  - [ ] Other

**Is your feature request related to a problem? How pervasive is the problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here. Any additional information about the device or system you would be using (e.g., RAM capacity, data set, and network bandwidth). 